==> masm-cdb-0.0.1.tgz: package/main.js <==
var _     = require("underscore");
var http  = require("http");
var utils = require("masm-util");

function Server(host, port, username, password) {
    this.host = host;
    this.port = port;
    if (username) {
        this.authStr = "Basic " + new Buffer(username + ":" + password).toString("base64");
    }
}

Server.prototype = {
    request: function(method, path, query, callback) {
        method = method.toUpperCase();
        return http.request({
            host: this.host,
            port: this.port,
            path: utils.url(path, query),
            method: method,
            headers: defaultHeadersForMethod(method)
        }, callback);
    },

    get: function(path, query, callback) {
        return http.get({
            host: this.host,
            port: this.port,
            path: utils.url(path, query),
            headers: defaultHeadersForMethod("GET")
        }, callback);
    },

    getWithHeaders: function(path, query, headers, callback) {
        _.defaults(headers, defaultHeadersForMethod("GET"));
        return http.get({
            host: this.host,
            port: this.port,
            path: utils.url(path, query),
            headers: headers
        }, callback);
    },

    put: function(path, query, callback) {
        return this.request("PUT", path, query, callback);
    },

    post: function(path, query, callback) {
        return this.request("POST", path, query, callback);
    },

    delete: function(path, query, callback) {
        return this.request("DELETE", path, query, callback);
    },

    requestJSON: function(method, path, query, callback) {
        var req = this.request(method, path, query, utils.withJSONFromBody(function (data) {
            if (data.error) {
                return callback(data, null);
            } else {
                return callback(null, data);
            }
        }));
        req.on("error", function(e) {
            callback({error:"internal server error", reason: "access to couchdb failed", message: e.message});
        });
        return req;
    },

    getJSON: function(path, query, callback) {
        var req = this.get(path, query, utils.withJSONFromBody(function (data) {
            if (data.error) {
                return callback(data, null);
            } else {
                return callback(null, data);
            }
        }));
        req.on("error", function(e) {
            callback({error:"internal server error", reason: "access to couchdb failed", message: e.message});
        });
        return req;
    },

    getJSONWithHeaders: function(path, query, headers, callback) {
        var req = this.getWithHeaders(path, query, headers, utils.withJSONFromBody(function (data) {
            if (data.error) {
                return callback(data, null);
            } else {
                return callback(null, data);
            }
        }));
        req.on("error", function(e) {
            callback({error:"internal server error", reason: "access to couchdb failed", message: e.message});
        });
        return req;
    },

    putJSON: function(path, query, callback) {
        return this.requestJSON("PUT", path, query, callback);
    },

    postJSON: function(path, query, callback) {
        return this.requestJSON("POST", path, query, callback);
    },

    deleteJSON: function(path, query, callback) {
        return this.requestJSON("DELETE", path, query, callback);
    },

    defaultHeadersForMethod: function (method) {
        var o = {"Accept": "application/json"};
        if (this.auth) {
            _.extend(o, {"Authorization": authStr});
        }
        switch (method.toUpperCase()) {
        case "PUT": case "POST":
            _.extend(o, {"Content-Type": "application/json"});
            break;
        default:
            break;
        }
        return o;
    }
};

function connection(host, port, username, password) {
    return new Server(host, port, username, password);
}

module.exports = {
    connection: connection
};

==> masm-cdb-0.0.2.tgz: package/main.js <==
var _     = require("underscore");
var http  = require("http");
var utils = require("masm-util");

function Server(host, port, username, password) {
    this.host = host;
    this.port = port;
    if (username) {
        this.authStr = "Basic " + new Buffer(username + ":" + password).toString("base64");
    }
}

Server.prototype = {
    request: function(method, path, query, callback) {
        method = method.toUpperCase();
        return http.request({
            host: this.host,
            port: this.port,
            path: utils.url(path, query),
            method: method,
            headers: this.defaultHeadersForMethod(method)
        }, callback);
    },

    get: function(path, query, callback) {
        return http.get({
            host: this.host,
            port: this.port,
            path: utils.url(path, query),
            headers: this.defaultHeadersForMethod("GET")
        }, callback);
    },

    getWithHeaders: function(path, query, headers, callback) {
        _.defaults(headers, this.defaultHeadersForMethod("GET"));
        return http.get({
            host: this.host,
            port: this.port,
            path: utils.url(path, query),
            headers: headers
        }, callback);
    },

    put: function(path, query, callback) {
        return this.request("PUT", path, query, callback);
    },

    post: function(path, query, callback) {
        return this.request("POST", path, query, callback);
    },

    delete: function(path, query, callback) {
        return this.request("DELETE", path, query, callback);
    },

    requestJSON: function(method, path, query, callback) {
        var req = this.request(method, path, query, utils.withJSONFromBody(function (data) {
            if (data.error) {
                return callback(data, null);
            } else {
                return callback(null, data);
            }
        }));
        req.on("error", function(e) {
            callback({error:"internal server error", reason: "access to couchdb failed", message: e.message});
        });
        return req;
    },

    getJSON: function(path, query, callback) {
        var req = this.get(path, query, utils.withJSONFromBody(function (data) {
            if (data.error) {
                return callback(data, null);
            } else {
                return callback(null, data);
            }
        }));
        req.on("error", function(e) {
            callback({error:"internal server error", reason: "access to couchdb failed", message: e.message});
        });
        return req;
    },

    getJSONWithHeaders: function(path, query, headers, callback) {
        var req = this.getWithHeaders(path, query, headers, utils.withJSONFromBody(function (data) {
            if (data.error) {
                return callback(data, null);
            } else {
                return callback(null, data);
            }
        }));
        req.on("error", function(e) {
            callback({error:"internal server error", reason: "access to couchdb failed", message: e.message});
        });
        return req;
    },

    putJSON: function(path, query, callback) {
        return this.requestJSON("PUT", path, query, callback);
    },

    postJSON: function(path, query, callback) {
        return this.requestJSON("POST", path, query, callback);
    },

    deleteJSON: function(path, query, callback) {
        return this.requestJSON("DELETE", path, query, callback);
    },

    defaultHeadersForMethod: function (method) {
        var o = {"Accept": "application/json"};
        if (this.auth) {
            _.extend(o, {"Authorization": authStr});
        }
        switch (method.toUpperCase()) {
        case "PUT": case "POST":
            _.extend(o, {"Content-Type": "application/json"});
            break;
        default:
            break;
        }
        return o;
    }
};

function connection(host, port, username, password) {
    return new Server(host, port, username, password);
}

module.exports = {
    connection: connection
};
